#A data-intensive assessment of the species abundance distribution.
#Abstract
<!-- 350 words or less, no subheading, citations, drawings, diagrams, tables, or abbreviations.  Include total number of pages in the paper (including preliminary pages and appendices) in parentheses at the end, do not use boldface on the abstract title, see sample in Appendix A of grad school Pub Guide.-->
The hollow curve species abundance distribution describes the pattern of large numbers of rare species and a small number of common species in a community.  The species abundance distribution is one of the most ubiquitous patterns in nature and many models have been proposed to explain the mechanisms that generate this pattern. While there have been numerous comparisons of species abundance distribution models, most of these comparisons only use only a small subset of available models, focus on a single ecosystem or taxonomic group, and fail to use the most appropriate statistical methods. This makes it difficult to draw general conclusions about which, if any, models provide the best empirical fit to species abundance distributions. I compiled data from the literature to significantly expand the available data for underrepresented taxonomic groups, and combined this with other macroecological datasets to perform comprehensive model comparisons for the species abundance distribution. A multiple model comparison showed that most available models for the species abundance distribution fit the data equivalently well across a diverse array of ecosystems and taxonomic groups. In addition, a targeted comparison of the species abundance distribution predicted by a major ecological theory, the unified neutral theory of biodiversity (neutral theory), against a non-neutral model of species abundance, demonstrates that it is difficult to distinguish between these two classes of theory based on patterns in the species abundance distribution. In concert, these studies call into question the potential for using the species abundance distribution to infer the processes operating in ecological systems.

(XXX pages)

#Public abstract
<!-- One page, written in the style of an executive summary, whatever that means.  Explains in common language the research objective and societal benefits, see Appendix A -->
One of the most commonly observed patterns in ecology is that fact that at most locations there are a large number of relatively rare species, composed of only a few individuals per species, and a small number of relatively common species. This pattern of commonness and rarity is quantified by the species abundance distribution.

As one of the most commonly observed patterns in ecology, it has been studied intensively for over 100 years. A major emphasis of this research has been developing models to try to understand the forces that generate such a general pattern. As a result, there are now dozens of different models for how this pattern might be generated, and these models are based on at least five different major categories of forces. Since many of these models appear to match ecological observations reasonably well, it is difficult to tell which model or models are most likely to be correct.

In order to address this issue I compiled data on over 16,000 ecological systems. I then used the best available statistical methods to compare a number of different models to observed data. While there have been numerous comparisons of species abundance distribution models, most of these comparisons only use only a small subset of available models, focus on a single ecosystem or type of species, and fail to use the most appropriate statistical methods. My approach overcomes all of these challenges and thus provides the best opportunity for figuring out which models provide the best description of real data.

Both broad stroke and detailed comparisons of this pattern of commonness and rarity suggest that even when using large amounts of data from across the world and the diversity of life, and the most current and powerful statistical methods, that it is generally not possible to distinguish between many common models of the species abundance distribution. I could exclude some models as clearly poorer descriptions of the pattern than others, but several models provided equivalently good descriptions of the data. This calls into question the potential for using the species abundance distribution to understand what processes are driving ecological systems.

#Introduction
<!--Overarching introduction that ties all three chapters together -->
Macroecology is a data-intensive approach to studying ecological patterns and processes. As the field has matured, increasingly greater amounts of data have become available to address these questions [@reichman2011challenges].  Although the macroecological research program has matured a great deal since its introduction [@mcgill2010mechanisms; @keith2012macroecology], there are still a number of areas in which it can be improved [@beck2012s]. One of the major criticisms of macroecology is that it is biased towards analyzing data from terrestrial systems in North America [@beck2012s], a legacy of the academic heritage of the scientists who developed macroecology, as well as the availability of large ecological datasets suitable for testing macroecological questions.  Another major criticism has been that the field focuses too much on pattern description, and not enough on the identification of pattern generating mechanisms [@beck2012s].
<!-- cite some of the recent critiques and directional papers -->

One of the most significant patterns in macroecology is the species abundance distribution, which describes the commonness and rarity of species in an ecological community. The form of this pattern is very general, with most communities being composed of a small number of common species and a large number of rare species. Interest in this pattern has generated dozens of models attempting to characterize the form of the pattern and the processes underlying it. However, most attempts to determine which of these models provide the best fit to empirical data, and are therefore most likely to describe the processes generating the pattern, have been limited either by a combination of poor statistical methodology and/or restricted scope.

A set of best practices for testing patterns and models in macroecology has been developed as the discipline has matured [@mcgill2003; @mcgill2006; @white2008; @burnham2002; @white2012]. Some of these best practices for testing macroecological theory include: <!--citations-->  
* Testing the generality of patterns with multiple taxonomic groups/ecosystems, both terrestrial and aquatic/marine [@white2012].
* Simultaneous testing of multiple models and model predictions [@mcgill2003; @mcgill2006]
* Use of likelihood based methods for comparing distributions [@edwards2007; @white2008]

Following these best practices allows for a more rigorous assessment of the generality of patterns across taxonomic groups/ecosystems, may provide better insight into identifying pattern generating mechanisms, and improve the ability to make ecological predictions. Here I present research following best practices for comparing species abundance distributions by compiling a unique dataset for addressing macroecological questions for more ecosystems and taxonomic groups, evaluate multiple competing models, and use the best statistical methods available.

First, to address some of the concerns about the lack of data for underrepresented taxonomic groups and ecosystems, I compiled a set of data from the literature.  My primary focus for data collection was to collect data for those vertebrate taxa which are not already well represented by publicly available data.  I selected these taxa because their taxonomy is fairly well resolved when compared to the majority of invertebrate groups.  While my primary focus was on fish, reptiles, and amphibians, I also compiled data on spiders and beetles.  In addition, I also collected a small amount of bird data, which could potentially be used in comparision with the large, publicly available bird datasets to determine if the dataset affects the results.

Second,  we compete five models from each of four different model families: purely statistical, branching process, population dynamics, and niche partitioning [@mcgill2007] with community abundance data for reptiles, amphibians, bony fish, beetles, spiders, birds, trees, mammals, and butterflies to perform the largest test of species abundance distributions to date. We follow the current best practice recommendations for testing species abundance distribution models to determine which models provide the best fit to empirical data.  Identifying which, if any, models best describe the data can help determine what pattern generating mechanisms are more likely to have direct influences on the shape of the species abundance distribution.

Third, we expand our exploration of the hollow curve species abundance distribution by performing a detailed analysis evaluating previous work on marine systems by Connolly et al. 2014 to determine if species abundance data is sufficient for identifying two general classes of ecological process, neutral vs. non-neutral processes [@connolly2014]. Connolly et al. found that the majority of sites were best described by a non-neutral model of species abundance in marine ecosystems; however, this has not yet been tested for terrestrial systems. This work seeks to determine the generality of the non-neutral species abundance distribution method in terrestrial systems, and identify whether there are differences between terrestrial and marine systems relative to species abundance distributions.
